'use strict';

var resolve = require('resolve');

var _require = require('../utils'),
    ifAnyDep = _require.ifAnyDep;

var isTest = process.env.NODE_ENV === 'test';
var isPreact = process.env.LIBRARY === 'preact';
var isRollup = JSON.parse(process.env.ROLLUP_BUILD || 'false');
var isWebpack = JSON.parse(process.env.WEBPACK_BUILD || 'false');
var treeshake = isRollup || isWebpack;

var resolvePreset = function resolvePreset(name) {
  return resolve.sync(`babel-preset-${name}`, { basedir: __dirname });
};
var resolvePlugin = function resolvePlugin(name) {
  return resolve.sync(`babel-plugin-${name}`, { basedir: __dirname });
};

module.exports = {
  presets: [[resolvePreset('env'), treeshake ? { modules: false } : {
    targets: {
      node: '4.5'
    }
  }], ifAnyDep('react', resolvePreset('react'))].filter(Boolean),
  plugins: [isRollup ? resolvePlugin('external-helpers') : null,
  // we're actually not using JSX at all, but I'm leaving this
  // in here just in case we ever do (this would be easy to miss).
  isPreact ? [resolvePlugin('transform-react-jsx'), { pragma: 'h' }] : null, isPreact ? [resolvePlugin('transform-react-remove-prop-types'), { removeImport: true }] : null, isTest || isRollup ? resolvePlugin('transform-inline-environment-variables') : null, resolvePlugin('transform-class-properties'), resolvePlugin('transform-object-rest-spread')].filter(Boolean)
};